==> haskell-hs-bibutils-6.10.0.0-220-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hs-bibutils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hs-bibutils
version:              6.10.0.0
visibility:           public
id:                   hs-bibutils-6.10.0.0-LXYgW7U36ejFefMjHnBuE
key:                  hs-bibutils-6.10.0.0-LXYgW7U36ejFefMjHnBuE
license:              LicenseRef-GPL
maintainer:           Václav Haisman <vhaisman@gmail.com>
author:               Andrea Rossato
homepage:             https://github.com/wilx/hs-bibutils
synopsis:
    Haskell bindings to bibutils, the bibliography
    conversion utilities.

description:
    Haskell bindings to Chris Putnam'\''s bibutils, a
    library that interconverts between various
    bibliography formats using a common MODS-format
    XML intermediate.

    hs-bibutils is available under the GNU GPL license. See
    the LICENSE file for details.

    For more details about bibutils, please check:
    <http://sourceforge.net/p/bibutils/home/Bibutils/>.

    The package release number refers to the release number of
    the included bibutils library.

category:             Text
abi:                  be3bc35e361a92b7f5fd14df4924b594
exposed:              True
exposed-modules:      Text.Bibutils
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hs-bibutils-6.10.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hs-bibutils-6.10.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hs-bibutils-6.10.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hs-bibutils
hs-libraries:         HShs-bibutils-6.10.0.0-LXYgW7U36ejFefMjHnBuE
includes:             bibutils.h
depends:              base-4.17.2.1 syb-0.7.3-Lap6GPARkRXCVbqA2faY6P
haddock-interfaces:   /usr/share/doc/haskell-hs-bibutils/html/hs-bibutils.haddock
haddock-html:         /usr/share/doc/haskell-hs-bibutils/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hs-bibutils-6.10.0.0-222-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hs-bibutils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hs-bibutils
version:              6.10.0.0
visibility:           public
id:                   hs-bibutils-6.10.0.0-B1LmeTOgDd0378hLqvEAMQ
key:                  hs-bibutils-6.10.0.0-B1LmeTOgDd0378hLqvEAMQ
license:              LicenseRef-GPL
maintainer:           Václav Haisman <vhaisman@gmail.com>
author:               Andrea Rossato
homepage:             https://github.com/wilx/hs-bibutils
synopsis:
    Haskell bindings to bibutils, the bibliography
    conversion utilities.

description:
    Haskell bindings to Chris Putnam'\''s bibutils, a
    library that interconverts between various
    bibliography formats using a common MODS-format
    XML intermediate.

    hs-bibutils is available under the GNU GPL license. See
    the LICENSE file for details.

    For more details about bibutils, please check:
    <http://sourceforge.net/p/bibutils/home/Bibutils/>.

    The package release number refers to the release number of
    the included bibutils library.

category:             Text
abi:                  5fbecb8fafaf42d6cec7b3134efd791d
exposed:              True
exposed-modules:      Text.Bibutils
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hs-bibutils-6.10.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hs-bibutils-6.10.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hs-bibutils-6.10.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hs-bibutils
hs-libraries:         HShs-bibutils-6.10.0.0-B1LmeTOgDd0378hLqvEAMQ
includes:             bibutils.h
depends:              base-4.17.2.1 syb-0.7.3-82kecYkSnotJhXSs3T6xq0
haddock-interfaces:   /usr/share/doc/haskell-hs-bibutils/html/hs-bibutils.haddock
haddock-html:         /usr/share/doc/haskell-hs-bibutils/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
